==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/cs.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Úložiště je dočasně nedostupné",
    "Storage invalid" : "Neplatné úložiště",
    "Unknown error" : "Neznámá chyba",
    "All files" : "Všechny soubory",
    "Recent" : "Nedávné",
    "Favorites" : "Oblíbené",
    "File could not be found" : "Soubor nelze nalézt",
    "Move or copy" : "Přesunout nebo zkopírovat",
    "Download" : "Stáhnout",
    "Delete" : "Smazat",
    "Home" : "Domů",
    "Close" : "Zavřít",
    "Could not create folder \"{dir}\"" : "Nelze vytvořit adresář \"{dir}\"",
    "Upload cancelled." : "Odesílání zrušeno.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nelze nahrát soubor {filename}, protože je to buď adresář nebo má velikost 0 bytů",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Není dostatek místa pro uložení, velikost souboru je {size1}, zbývá pouze {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Cílová složka „{dir}“ už neexistuje",
    "Not enough free space" : "Nedostatek volného prostoru",
    "Uploading …" : "Nahrávání…",
    "…" : "…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Cílový adresář už neexistuje",
    "Error when assembling chunks, status code {status}" : "Chyba při kompletaci kusů, kód chyby {status}",
    "Actions" : "Činnosti",
    "Rename" : "Přejmenovat",
    "Copy" : "Kopírovat",
    "Target folder" : "Cílový adresář",
    "Disconnect storage" : "Odpojit úložiště",
    "Unshare" : "Zrušit sdílení",
    "Could not load info for file \"{file}\"" : "Nepodařilo se načíst informace pro soubor {file}",
    "Files" : "Soubory",
    "Details" : "Podrobnosti",
    "Select" : "Vybrat",
    "Pending" : "Nevyřízené",
    "Unable to determine date" : "Nelze určit datum",
    "This operation is forbidden" : "Tato operace je zakázána",
    "This directory is unavailable, please check the logs or contact the administrator" : "Tento adresář není dostupný, zkontrolujte prosím logy nebo kontaktujte svého správce systému",
    "Could not move \"{file}\", target exists" : "Nelze přesunout \"{file}\", cíl existuje",
    "Could not move \"{file}\"" : "Nelze přesunout \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Nelze kopírovat \"{file}\", cíl již existuje",
    "Could not copy \"{file}\"" : "Nelze kopírovat \"{file}\"",
    "Copied {origin} inside {destination}" : "{origin} zkopírován do {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} a {nbfiles} dalších souborů zkopírováno do {destination}",
    "{newName} already exists" : "{newName} už existuje",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nelze přejmenovat \"{fileName}\", již neexistuje",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Jméno \"{targetName}\" je již použito v adresáři \"{dir}\". Vyberte prosím jiné jméno.",
    "Could not rename \"{fileName}\"" : "Nelze přejmenovat \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nelze vytvořit soubor \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nelze vytvořit soubor \"{file}\", protože již existuje",
    "Could not create folder \"{dir}\" because it already exists" : "Nelze vytvořit adresář \"{dir}\", protože již existuje",
    "Error deleting file \"{fileName}\"." : "Chyba mazání souboru \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Žádné výsledky hledání v ostatních složkách pro {tag}{filter}{endtag}",
    "Name" : "Název",
    "Size" : "Velikost",
    "Modified" : "Upraveno",
    "_%n folder_::_%n folders_" : ["%n adresář","%n adresáře","%n adresářů","%n adresářů"],
    "_%n file_::_%n files_" : ["%n soubor","%n soubory","%n souborů","%n souborů"],
    "{dirs} and {files}" : "{dirs} a {files}",
    "_including %n hidden_::_including %n hidden_" : ["přidán %n skrytý","přidány %n skryté","přidáno %n skrytých","přidáno %n skrytých"],
    "You don’t have permission to upload or create files here" : "Nemáte oprávnění sem nahrávat nebo vytvářet soubory",
    "_Uploading %n file_::_Uploading %n files_" : ["Nahrávám %n soubor","Nahrávám %n soubory","Nahrávám %n souborů","Nahrávám %n souborů"],
    "New" : "Nový",
    "{used} of {quota} used" : "Využito {used} z {quota} ",
    "{used} used" : "{used} Využito",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neplatným názvem souboru.",
    "File name cannot be empty." : "Název souboru nemůže být prázdný řetězec.",
    "\"/\" is not allowed inside a file name." : "\"/\" není povolený znak v názvu souboru",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" není povolený typ souboru",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Úložiště uživatele {owner} je zaplněné, soubory nelze aktualizovat a synchronizovat!",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložiště je plné, nelze aktualizovat ani synchronizovat soubory.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Úložiště uživatele {owner} je téměř plné ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaše úložiště je téměř plné ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["odpovídá '{filter}'","odpovídá '{filter}'","odpovídá '{filter}'","odpovídá '{filter}'"],
    "View in folder" : "Zobrazit v adresáři",
    "Copied!" : "Zkopírováno!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Zkopírovat přímý odkaz (funguje pouze pro uživatele, kteří mají přistup k tomuto souboru/adresáři)",
    "Path" : "Cesta",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtů","%n bajtů"],
    "Favorited" : "Přidáno k oblíbeným",
    "Favorite" : "Oblíbené",
    "New folder" : "Nový adresář",
    "Upload file" : "Nahrát soubor",
    "Not favorited" : "Nepřidáno do oblíbených",
    "Remove from favorites" : "Odebrat z oblíbených",
    "Add to favorites" : "Přidat do oblíbených",
    "An error occurred while trying to update the tags" : "Při pokusu o úpravu tagů nastala chyba",
    "Added to favorites" : "Přidán k oblíbeným",
    "Removed from favorites" : "Odebráno z oblíbených",
    "You added {file} to your favorites" : "Do svých oblíbených jste přidal(a) {file}",
    "You removed {file} from your favorites" : "Odstranil(a) jste {file} ze svých oblíbených",
    "File changes" : "Změny souboru",
    "Created by {user}" : "Vytvořil {user}",
    "Changed by {user}" : "Změnil {user}",
    "Deleted by {user}" : "Odstranil {user}",
    "Restored by {user}" : "Obnovil {user}",
    "Renamed by {user}" : "Přejmenoval {user}",
    "Moved by {user}" : "Přesunul {user}",
    "\"remote user\"" : "\"vzdálený uživatel\"",
    "You created {file}" : "Vytvořil(a) jste {file}",
    "You created an encrypted file in {file}" : "Vytvořili jste šifrovaný soubor  {file}",
    "{user} created {file}" : "{user} vytvořil(a) {file}",
    "{user} created an encrypted file in {file}" : "{user} vytvořil šifrovaný soubor {file}",
    "{file} was created in a public folder" : "Soubor {file} byl vytvořen ve veřejné složce",
    "You changed {file}" : "Změnil(a) jste {file}",
    "You changed an encrypted file in {file}" : "Změnili jste šifrovaný soubor {file}",
    "{user} changed {file}" : "{user} změnil(a) {file}",
    "{user} changed an encrypted file in {file}" : "{user} změnil šifrovaný soubor {file}",
    "You deleted {file}" : "Odstranil(a) jste {file}",
    "You deleted an encrypted file in {file}" : "Smazali jste šifrovaný soubor {file}",
    "{user} deleted {file}" : "{user} smazal(a) {file}",
    "{user} deleted an encrypted file in {file}" : "{user} smazal šifrovaný soubor {file}",
    "You restored {file}" : "Obnovil(a) jste {file}",
    "{user} restored {file}" : "{user} obnovil {file}",
    "You renamed {oldfile} to {newfile}" : "Přejmenoval(a) jste {oldfile} na {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} přejmenoval {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "{oldfile} jste přesunul(a) do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} přesunul(a) {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Soubor byl přidán, nebo odstraněn z vašich <strong>oblíbených</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Soubor nebo adresář byl <strong>změněn</strong> nebo <strong>přejmenován</strong>",
    "A new file or folder has been <strong>created</strong>" : "Byl <strong>vytvořen</strong> nový soubor nebo adresář",
    "A file or folder has been <strong>deleted</strong>" : "Soubor nebo adresář byl <strong>smazán</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Omezovat oznámení o tvorbě a změnách <strong>oblíbených souborů</strong> <em>(Pouze v proudu)</em>",
    "A file or folder has been <strong>restored</strong>" : "Soubor nebo adresář byl <strong>obnoven</strong>",
    "Unlimited" : "Neomezeně",
    "Upload (max. %s)" : "Nahrát (max. %s)",
    "File Management" : "Správa souborů",
    "File handling" : "Zacházení se soubory",
    "Maximum upload size" : "Maximální velikost pro odesílání",
    "max. possible: " : "největší možná: ",
    "Save" : "Uložit",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Při použití PHP-FPM může změna nastavení trvat až 5 minut od uložení.",
    "Missing permissions to edit from here." : "Pro úpravy v aktuálním náhledu chybí oprávnění.",
    "%s of %s used" : "%s z %s použito",
    "%s used" : "%s použito",
    "Settings" : "Nastavení",
    "Show hidden files" : "Zobrazit skryté soubory",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Použijte tuto adresu pro <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">přístup k vašim souborům přes WebDAV</a>",
    "Cancel upload" : "Zrušit nahrávání",
    "No files in here" : "Žádné soubory",
    "Upload some content or sync with your devices!" : "Nahrajte nějaký obsah nebo synchronizujte se svými přístroji!",
    "No entries found in this folder" : "V tomto adresáři nebylo nic nalezeno",
    "Select all" : "Vybrat vše",
    "Upload too large" : "Odesílaný soubor je příliš velký",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Soubory, které se snažíte odeslat, překračují limit velikosti odesílání na tomto serveru.",
    "No favorites yet" : "Zatím nic oblíbeného",
    "Files and folders you mark as favorite will show up here" : "Zde budou zobrazeny soubory a adresáře označené jako oblíbené",
    "Tags" : "Značky",
    "Deleted files" : "Odstraněné soubory",
    "Text file" : "Textový soubor",
    "New text file.txt" : "Nový textový soubor.txt",
    "Move" : "Přesunout",
    "A new file or folder has been <strong>deleted</strong>" : "Nový soubor nebo adresář byl <strong>smazán</strong>",
    "A new file or folder has been <strong>restored</strong>" : "Nový soubor nebo adresář byl <strong>obnoven</strong>",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Použít tuto adresu <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\"> pro přístup k souborům přes WebDAV</a>",
    "Shared with you" : "Sdíleno s vámi",
    "Shared with others" : "Sdíleno s ostatními",
    "Shared by link" : "Sdíleno pomocí odkazu"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/cs.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Úložiště je dočasně nedostupné",
    "Storage invalid" : "Neplatné úložiště",
    "Unknown error" : "Neznámá chyba",
    "All files" : "Všechny soubory",
    "Recent" : "Nedávné",
    "Favorites" : "Oblíbené",
    "File could not be found" : "Soubor se nedaří nalézt",
    "Move or copy" : "Přesunout nebo zkopírovat",
    "Download" : "Stáhnout",
    "Delete" : "Smazat",
    "Home" : "Domů",
    "Close" : "Zavřít",
    "Could not create folder \"{dir}\"" : "Nelze vytvořit složku „{dir}“",
    "Upload cancelled." : "Odesílání zrušeno.",
    "…" : "…",
    "Processing files …" : "Zpracovávání souborů…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nelze nahrát soubor {filename}, protože je to buď adresář nebo má velikost 0 bytů",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Není dostatek místa pro uložení, velikost souboru je {size1}, zbývá pouze {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Cílová složka „{dir}“ už neexistuje",
    "Not enough free space" : "Nedostatek volného prostoru",
    "Uploading …" : "Nahrávání…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Nahrání této položky není podporováno",
    "Target folder does not exist any more" : "Cílová složka už neexistuje",
    "Error when assembling chunks, status code {status}" : "Chyba při kompletaci shluků, kód chyby {status}",
    "Actions" : "Činnosti",
    "Rename" : "Přejmenovat",
    "Copy" : "Kopírovat",
    "Disconnect storage" : "Odpojit úložiště",
    "Unshare" : "Zrušit sdílení",
    "Could not load info for file \"{file}\"" : "Nepodařilo se načíst informace pro soubor {file}",
    "Files" : "Soubory",
    "Details" : "Podrobnosti",
    "Select" : "Vybrat",
    "Pending" : "Nevyřízené",
    "Unable to determine date" : "Nelze určit datum",
    "This operation is forbidden" : "Tato operace je zakázána",
    "This directory is unavailable, please check the logs or contact the administrator" : "Tento adresář není dostupný, zkontrolujte záznamy událostí nebo se obraťte na správce",
    "Could not move \"{file}\", target exists" : "Nelze přesunout „{file}“, cíl existuje",
    "Could not move \"{file}\"" : "Nelze přesunout „{file}“",
    "Could not copy \"{file}\", target exists" : "Nelze kopírovat „{file}“, cíl už existuje",
    "Could not copy \"{file}\"" : "Nelze kopírovat „{file}“",
    "Copied {origin} inside {destination}" : "{origin} zkopírován do {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} a {nbfiles} dalších souborů zkopírováno do {destination}",
    "{newName} already exists" : "{newName} už existuje",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nelze přejmenovat „{fileName}“, už neexistuje",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Název „{targetName}“ je už použito ve složce „{dir}“. Zvolte jiný název.",
    "Could not rename \"{fileName}\"" : "Nelze přejmenovat „{fileName}“",
    "Could not create file \"{file}\"" : "Nelze vytvořit soubor „{file}“",
    "Could not create file \"{file}\" because it already exists" : "Nelze vytvořit soubor „{file}“, protože už existuje",
    "Could not create folder \"{dir}\" because it already exists" : "Nelze vytvořit složku „{dir}“, protože už existuje",
    "Error deleting file \"{fileName}\"." : "Chyba mazání souboru „{fileName}“.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Žádné výsledky hledání v ostatních složkách pro {tag}{filter}{endtag}",
    "Name" : "Název",
    "Size" : "Velikost",
    "Modified" : "Upraveno",
    "_%n folder_::_%n folders_" : ["%n šložka","%n složky","%n složek","%n složky"],
    "_%n file_::_%n files_" : ["%n soubor","%n soubory","%n souborů","%n souborů"],
    "{dirs} and {files}" : "{dirs} a {files}",
    "_including %n hidden_::_including %n hidden_" : ["přidán %n skrytý","přidány %n skryté","přidáno %n skrytých","přidáno %n skrytých"],
    "You don’t have permission to upload or create files here" : "Nemáte oprávnění sem nahrávat nebo vytvářet soubory",
    "_Uploading %n file_::_Uploading %n files_" : ["Nahrává se %n soubor","Nahrávají se %n soubory","Nahrává se %n souborů","Nahrávají se %n soubory"],
    "New" : "Nový",
    "{used} of {quota} used" : "Využito {used} z {quota} ",
    "{used} used" : "{used} Využito",
    "\"{name}\" is an invalid file name." : "„{name}“ není platným názvem souboru.",
    "File name cannot be empty." : "Je třeba vyplnit název souboru.",
    "\"/\" is not allowed inside a file name." : "„/“ není povolený znak v názvu souboru.",
    "\"{name}\" is not an allowed filetype" : "„{name}“ není povolený typ souboru",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Úložiště uživatele {owner} je zaplněné, soubory nelze aktualizovat a synchronizovat!",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložiště je plné, nelze aktualizovat ani synchronizovat soubory.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Úložiště uživatele {owner} je téměř plné ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaše úložiště je téměř plné ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["odpovídá '{filter}'","odpovídá '{filter}'","odpovídá '{filter}'","odpovídá '{filter}'"],
    "View in folder" : "Zobrazit ve složce",
    "Copied!" : "Zkopírováno!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Zkopírovat přímý odkaz (funguje pouze pro uživatele, kteří mají přístup k tomuto souboru/složce)",
    "Path" : "Popis umístění",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtů","%n bajtů"],
    "Favorited" : "Přidáno k oblíbeným",
    "Favorite" : "Oblíbené",
    "New folder" : "Nová složka",
    "Upload file" : "Nahrát soubor",
    "Not favorited" : "Nepřidáno do oblíbených",
    "Remove from favorites" : "Odebrat z oblíbených",
    "Add to favorites" : "Přidat do oblíbených",
    "An error occurred while trying to update the tags" : "Při pokusu o úpravu štítků nastala chyba",
    "Added to favorites" : "Přidán k oblíbeným",
    "Removed from favorites" : "Odebráno z oblíbených",
    "You added {file} to your favorites" : "Do svých oblíbených jste přidali {file}",
    "You removed {file} from your favorites" : "Odstranili jste {file} ze svých oblíbených",
    "File changes" : "Změny souboru",
    "Created by {user}" : "Vytvořil(a) {user}",
    "Changed by {user}" : "Změnil(a) {user}",
    "Deleted by {user}" : "Odstranil(a) {user}",
    "Restored by {user}" : "Obnovil(a) {user}",
    "Renamed by {user}" : "Přejmenoval(a) {user}",
    "Moved by {user}" : "Přesunul(a) {user}",
    "\"remote user\"" : "„uživatel na protějšku“",
    "You created {file}" : "Vytvořili jste {file}",
    "You created an encrypted file in {file}" : "Vytvořili jste šifrovaný soubor  {file}",
    "{user} created {file}" : "{user} vytvořil(a) {file}",
    "{user} created an encrypted file in {file}" : "{user} vytvořil šifrovaný soubor {file}",
    "{file} was created in a public folder" : "Soubor {file} byl vytvořen ve veřejné složce",
    "You changed {file}" : "Změnil(a) jste {file}",
    "You changed an encrypted file in {file}" : "Změnili jste šifrovaný soubor {file}",
    "{user} changed {file}" : "{user} změnil(a) {file}",
    "{user} changed an encrypted file in {file}" : "{user} změnil(a) šifrovaný soubor {file}",
    "You deleted {file}" : "Odstranil(a) jste {file}",
    "You deleted an encrypted file in {file}" : "Smazali jste šifrovaný soubor {file}",
    "{user} deleted {file}" : "{user} smazal(a) {file}",
    "{user} deleted an encrypted file in {file}" : "{user} smazal šifrovaný soubor {file}",
    "You restored {file}" : "Obnovili jste {file}",
    "{user} restored {file}" : "{user} obnovil(a) {file}",
    "You renamed {oldfile} to {newfile}" : "Přejmenoval(a) jste {oldfile} na {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} přejmenoval(a) {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "{oldfile} jste přesunul(a) do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} přesunul(a) {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Soubor byl přidán, nebo odstraněn z vašich <strong>oblíbených</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Soubor nebo adresář byl <strong>změněn</strong> nebo <strong>přejmenován</strong>",
    "A new file or folder has been <strong>created</strong>" : "Byl <strong>vytvořen</strong> nový soubor nebo složka",
    "A file or folder has been <strong>deleted</strong>" : "Soubor nebo složka byla <strong>smazána</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Omezovat oznámení o tvorbě a změnách <strong>oblíbených souborů</strong> <em>(Pouze v proudu)</em>",
    "A file or folder has been <strong>restored</strong>" : "Soubor nebo složka byla <strong>obnovena</strong>",
    "Unlimited" : "Neomezeně",
    "Upload (max. %s)" : "Nahrát (max. %s)",
    "File Management" : "Správa souboru",
    "File handling" : "Zacházení se soubory",
    "Maximum upload size" : "Maximální velikost pro odesílání",
    "max. possible: " : "největší možná: ",
    "Save" : "Uložit",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Při použití PHP-FPM může změna nastavení trvat až 5 minut od uložení.",
    "Missing permissions to edit from here." : "Pro úpravy v aktuálním náhledu chybí oprávnění.",
    "%s used" : "%s použito",
    "Settings" : "Nastavení",
    "Show hidden files" : "Zobrazit skryté soubory",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Použijte tuto adresu pro <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">přístup k vašim souborům přes WebDAV</a>",
    "Cancel upload" : "Zrušit nahrávání",
    "No files in here" : "Žádné soubory",
    "Upload some content or sync with your devices!" : "Nahrajte nějaký obsah nebo synchronizujte se svými přístroji!",
    "No entries found in this folder" : "V této složce nebylo nic nalezeno",
    "Select all" : "Vybrat vše",
    "Upload too large" : "Odesílaný soubor je příliš velký",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Soubory, které se snažíte odeslat, překračují limit velikosti odesílání na tomto serveru.",
    "No favorites yet" : "Zatím nic oblíbeného",
    "Files and folders you mark as favorite will show up here" : "Zde budou zobrazeny soubory a složky označené jako oblíbené",
    "Tags" : "Značky",
    "Deleted files" : "Odstraněné soubory",
    "Shares" : "Sdílení",
    "Shared with others" : "Sdíleno s ostatními",
    "Shared with you" : "Sdíleno s vámi",
    "Shared by link" : "Sdíleno pomocí odkazu",
    "Deleted shares" : "Smazaná sdílení",
    "Text file" : "Textový soubor",
    "New text file.txt" : "Nový textový soubor.txt",
    "Move" : "Přesunout",
    "Target folder" : "Cílový adresář",
    "A new file or folder has been <strong>deleted</strong>" : "Nový soubor nebo složka byla <strong>smazána</strong>",
    "A new file or folder has been <strong>restored</strong>" : "Nový soubor nebo složka byla <strong>obnovena</strong>",
    "%s of %s used" : "%s z %s použito",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Použít tuto adresu <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\"> pro přístup k souborům přes WebDAV</a>"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
